# AramEau - pyeau 

## SCPUP Description

Library for Super Crystal Pokebros Ultimate Party game. This library contains the SCPUP ABC and related python classes

This library is not meant to be used in other projects other than AramEau's SCPUP and maybe other games made by AramEau. So, if for any reason you decide to use this library, it is at your own risk. Sorry but the aim of this library is to acomplish a personal goal.

## Install

Run `python -m pip install scpup`

## Usage example

```python
from scpup.abc import EauSprite

class EauSpriteImpl(EauSprite):
  ...
```

## Modules / Classes / Functions

WIP
